@@ -1,14 +1,13 @@
 import re
 import json
 
-import typedpy
-from typedpy import ImmutableStructure, String, Structure
+from typedpy import ImmutableStructure, String, Structure, AnyOf, Array
 
 
 class ErrorInfo(ImmutableStructure):
     field = String
     value = String
-    problem = String
+    problem = AnyOf[String, Array]
     _required = ["problem"]
 
 
@@ -29,7 +28,7 @@ def _transform_class_to_readable(problem: str):
     return problem
 
 
-_pattern_for_typepy_validation_1 = re.compile(r"^([a-zA-Z0-9_]+): Got (.*); (.*)$")
+_pattern_for_typepy_validation_1 = re.compile(r"^([a-zA-Z0-9_]+): Got ([^;]*); (.*)$")
 _pattern_for_typepy_validation_2 = re.compile(r"^([a-zA-Z0-9_]+):\s(.*); Got (.*)$")
 _pattern_for_typepy_validation_3 = re.compile(r"^([a-zA-Z0-9_]+):\s(.*)$")
 
@@ -43,24 +42,32 @@ def standard_readable_error_for_typedpy_exception(e: Exception):
         return [_standard_readable_error_for_typedpy_exception_internal(e) for e in errs]
 
 
-
 def _standard_readable_error_for_typedpy_exception_internal(err_message: str):
+    def try_expand(problem_str):
+        if not Structure.failing_fast():
+            try:
+                return standard_readable_error_for_typedpy_exception(Exception(problem_str))
+            except Exception:
+                pass
+        return problem_str
 
     match = _pattern_for_typepy_validation_1.match(err_message)
     if match:
+        problem = _transform_class_to_readable(match.group(3))
         return ErrorInfo(value=match.group(2),
-                         problem=_transform_class_to_readable(match.group(3)),
+                         problem=try_expand(problem),
                          field=match.group(1))
 
     match = _pattern_for_typepy_validation_2.match(err_message)
     if match:
+        problem = _transform_class_to_readable(match.group(2))
         return ErrorInfo(value=match.group(3),
-                         problem=_transform_class_to_readable(match.group(2)),
+                         problem=try_expand(problem),
                          field=match.group(1))
 
     match = _pattern_for_typepy_validation_3.match(err_message)
     if match:
         field = match.group(1)
         problem = _transform_class_to_readable(match.group(2))
-        return ErrorInfo(problem=problem, field=field)
-    return ErrorInfo(problem=err_message)
\ No newline at end of file
+        return ErrorInfo(problem=try_expand(problem), field=field)
+    return ErrorInfo(problem=err_message)
